@@ -41,6 +41,10 @@ def song_from_dictionary(dictionary: dict) -> Song:
     content = dictionary['content']
     for song_part in content:
         output.add_song_part(song_part_from_dictionary(song_part))
+    if 'transposition' in dictionary:
+        output = transpose_by_semitones(output, dictionary['transposition'])
+    if 'truncation' in dictionary:
+        output.content = output.content[:dictionary['truncation']]
     return output
 
 
@@ -75,5 +79,4 @@ if __name__ == '__main__':
     song = json.load(file)
     file.close()
     song = song_from_dictionary(song)
-    transpose_by_semitones(song, 8)
     print(SimplePrinter().print(song))
